% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quote.r
\name{print.quoted}
\alias{print.quoted}
\title{Print quoted variables.}
\usage{
\method{print}{quoted}(x, ...)
}
\description{
Display the \code{\link{str}}ucture of quoted variables
}
\keyword{internal}
