% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dimensions.r
\name{dims}
\alias{dims}
\title{Number of dimensions.}
\usage{
dims(x)
}
\arguments{
\item{x}{array}
}
\description{
Number of dimensions of an array or vector
}
\keyword{internal}
