% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dimensions.r
\name{reduce_dim}
\alias{reduce_dim}
\title{Reduce dimensions.}
\usage{
reduce_dim(x)
}
\arguments{
\item{x}{array}
}
\description{
Remove extraneous dimensions
}
\keyword{internal}
