% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/id.r
\name{id_var}
\alias{id_var}
\title{Numeric id for a vector.}
\usage{
id_var(x, drop = FALSE)
}
\description{
Numeric id for a vector.
}
\keyword{internal}
