% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.r
\name{unrowname}
\alias{unrowname}
\title{Un-rowname.}
\usage{
unrowname(x)
}
\arguments{
\item{x}{data frame}
}
\description{
Strip rownames from an object
}
\keyword{internal}
